==> nextcloud-php72-19.0.3.txz: usr/local/www/nextcloud/apps-pkg/dav/l10n/gl.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Calendario",
    "Todos" : "Asuntos pendentes",
    "Personal" : "Persoal",
    "{actor} created calendar {calendar}" : "{actor} creou o calendario {calendar}",
    "You created calendar {calendar}" : "Vostede creou o calendario {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} eliminou o calendario {calendar}",
    "You deleted calendar {calendar}" : "Vostede eliminou o calendario {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} actualizou o calendario {calendar}",
    "You updated calendar {calendar}" : "Vostede actualizou o calendario {calendar}",
    "You shared calendar {calendar} as public link" : "Vostede compartiu o calendario {calendar} como ligazón pública",
    "You removed public link for calendar {calendar}" : "Vostede retirou a ligazón pública do calendario {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} compartiu o calendario {calendar} con vostede",
    "You shared calendar {calendar} with {user}" : "Vostede compartiu o calendario {calendar} con {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} compartiu o calendario {calendar} con {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} deixou de compartir o calendario {calendar} de vostede",
    "You unshared calendar {calendar} from {user}" : "Vostede deixou de compartir o calendario {calendar} de {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} deixou de compartir o calendario {calendar} de {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} deixou de compartir o seu propio calendario {calendar}",
    "You shared calendar {calendar} with group {group}" : "Vostede compartiu o calendario {calendar} co grupo {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} compartiu o calendario {calendar} co grupo {group}",
    "You unshared calendar {calendar} from group {group}" : "Vostede deixou de compartir o calendario {calendar} do grupo {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} deixou de compartir o calendario {calendar} do grupo {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} creou o evento {event} no calendario {calendar}",
    "You created event {event} in calendar {calendar}" : "Vostede creou o evento {event} no calendario {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} eliminou o evento {event} do calendario {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Vostede eliminou o evento {event} do calendario {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} actualizou o evento {event} no calendario {calendar}",
    "You updated event {event} in calendar {calendar}" : "Vostede actualizou o evento {event} no calendario {calendar}",
    "Busy" : "Ocupado",
    "{actor} created todo {todo} in list {calendar}" : "{actor} creou os asuntos pendentes {todo} na lista {calendar}",
    "You created todo {todo} in list {calendar}" : "Vostede creou os asuntos pendentes {todo} na lista {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} eliminou os asuntos pendentes {todo} da lista {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Vostede eliminou os asuntos pendentes {todo} da lista {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} actualizou os asuntos pendentes {todo} na lista {calendar}",
    "You updated todo {todo} in list {calendar}" : "Vostede actualizou os asuntos pendentes {todo} na lista {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} resolveu os asuntos pendentes {todo} na lista {calendar}",
    "You solved todo {todo} in list {calendar}" : "Vostede resolveu os asuntos pendentes {todo} na lista {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} volveu abrir os asuntos pendentes {todo} na lista {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Vostede volveu abrir os asuntos pendentes {todo} na lista {calendar}",
    "Calendar and tasks" : "Calendario e tarefas",
    "A <strong>calendar</strong> was modified" : "Foi modificado un <strong>calendario</strong>",
    "A calendar <strong>event</strong> was modified" : "Foi modificado un <strong>evento</strong> do calendario",
    "A calendar <strong>todo</strong> was modified" : "Foi modificado un <strong>asunto pendente</strong> do calendario",
    "Death of %s" : "Falecemento de %s",
    "Contact birthdays" : "Aniversario do contacto",
    "Calendar:" : "Calendario:",
    "Date:" : "Data:",
    "Where:" : "Onde:",
    "Description:" : "Descrición:",
    "Untitled event" : "Evento sen título",
    "_%n year_::_%n years_" : ["%n ano","%n anos"],
    "_%n month_::_%n months_" : ["%n mes","%n meses"],
    "_%n day_::_%n days_" : ["%n día","%n días"],
    "_%n hour_::_%n hours_" : ["%n hora","%n horas"],
    "_%n minute_::_%n minutes_" : ["%n minuto","%n minutos"],
    "%s (in %s)" : "%s (n %s)",
    "%s (%s ago)" : "%s (hai %s)",
    "Calendar: %s" : "Calendario: %s",
    "Date: %s" : "Data: %s",
    "Description: %s" : "Descrición: %s",
    "Where: %s" : "Onde: %s",
    "%1$s via %2$s" : "%1$s mediante %2$s",
    "Invitation canceled" : "Convite cancelado",
    "Invitation updated" : "Convite actualizado",
    "Invitation" : "Convite",
    "Title:" : "Título:",
    "Time:" : "Hora:",
    "Location:" : "Lugar:",
    "Link:" : "Ligazón:",
    "Organizer:" : "Organizador:",
    "Attendees:" : "Asistentes:",
    "Accept" : "Aceptar",
    "Decline" : "Declinar",
    "More options …" : "Máis opcións…",
    "More options at %s" : "Máis opcións en %s",
    "Contacts" : "Contactos",
    "System in maintenance mode." : "Sistema en modo de mantemento",
    "Upgrade needed" : "É necesario anovar actualizar",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "É preciso configurar o seu %s para que empregue HTTPS para poder usar CalDAV e CardDAV con iOS / macOS.",
    "Configures a CalDAV account" : "Configurar unha conta de CalDAV",
    "Configures a CardDAV account" : "Configurar unha conta de CardDAV",
    "Events" : "Eventos",
    "Tasks" : "Tarefas",
    "Untitled task" : "Tarefa sen título",
    "Completed on %s" : "Rematado o %s",
    "Due on %s by %s" : "Caduca o %s por %s",
    "Due on %s" : "Caduca o %s",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "Terminación WebDAV",
    "There was an error updating your attendance status." : "Produciuse un erro ao actualizar o seu estado de asistencia.",
    "Please contact the organizer directly." : "Contacte directamente co organizador.",
    "Are you accepting the invitation?" : "Acepta vostede o convite?",
    "Tentative" : "Tentativa",
    "Save" : "Gardar",
    "Your attendance was updated successfully." : "A súa asistencia foi actualizada satisfactoriamente.",
    "Calendar server" : "Servidor do calendario",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Instale tamén a {calendarappstoreopen}aplicación do Calendario{linkclose} ou {calendardocopen}conecte os seus escritorio e móbil para sincronizalos ↗{linkclose}.",
    "Send invitations to attendees" : "Enviar convites aos asistentes",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Asegúrese de ter configurado correctamente {emailopen}o servidor de correo-e{linkclose}.",
    "Automatically generate a birthday calendar" : "Xerar automaticamente o calendario de aniversarios",
    "Birthday calendars will be generated by a background job." : "O calendario de aniversarios xerase cun traballo en segundo plano",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Por isto, non estarán dispoñíbeis inmediatamente tras activalos, senón que aparecerán após certo tempo",
    "Send notifications for events" : "Enviar notificacións para eventos",
    "Notifications are sent via background jobs, so these must occur often enough." : "As notificacións enviaranse mediante procesos en segundo plano, polo que estes teñen que suceder con frecuencia.",
    "Enable notifications for events via push" : "Enviar notificacións para eventos mediante «push»",
    "Hello %s," : "Ola %s,",
    "The meeting »%1$s« with %2$s was canceled." : "A xuntanza «%1$s» con %2$s foi cancelada.",
    "The meeting »%1$s« with %2$s was updated." : "A xuntanza «%1$s» con %2$s foi actualizada.",
    "%1$s invited you to »%2$s«" : "%1$s convidouno a «%2$s»",
    "When:" : "Cando:",
    "Technical details" : "Detalles técnicos",
    "Remote Address: %s" : "Enderezo remoto: %s",
    "Request ID: %s" : "ID da solicitude: %s",
    "Notifications will be send through background jobs, so these need to happen often enough." : "As notificacións enviaranse a través procesos en segundo plano, polo que estes teñen que suceder bastante a miúdo."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-php74-20.0.7.txz: usr/local/www/nextcloud/apps-pkg/dav/l10n/gl.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Calendario",
    "Todos" : "Asuntos pendentes",
    "Personal" : "Persoal",
    "{actor} created calendar {calendar}" : "{actor} creou o calendario {calendar}",
    "You created calendar {calendar}" : "Vostede creou o calendario {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} eliminou o calendario {calendar}",
    "You deleted calendar {calendar}" : "Vostede eliminou o calendario {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} actualizou o calendario {calendar}",
    "You updated calendar {calendar}" : "Vostede actualizou o calendario {calendar}",
    "You shared calendar {calendar} as public link" : "Vostede compartiu o calendario {calendar} como ligazón pública",
    "You removed public link for calendar {calendar}" : "Vostede retirou a ligazón pública do calendario {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} compartiu o calendario {calendar} con vostede",
    "You shared calendar {calendar} with {user}" : "Vostede compartiu o calendario {calendar} con {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} compartiu o calendario {calendar} con {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} deixou de compartir o calendario {calendar} de vostede",
    "You unshared calendar {calendar} from {user}" : "Vostede deixou de compartir o calendario {calendar} de {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} deixou de compartir o calendario {calendar} de {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} deixou de compartir o seu propio calendario {calendar}",
    "You shared calendar {calendar} with group {group}" : "Vostede compartiu o calendario {calendar} co grupo {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} compartiu o calendario {calendar} co grupo {group}",
    "You unshared calendar {calendar} from group {group}" : "Vostede deixou de compartir o calendario {calendar} do grupo {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} deixou de compartir o calendario {calendar} do grupo {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} creou o evento {event} no calendario {calendar}",
    "You created event {event} in calendar {calendar}" : "Vostede creou o evento {event} no calendario {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} eliminou o evento {event} do calendario {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Vostede eliminou o evento {event} do calendario {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} actualizou o evento {event} no calendario {calendar}",
    "You updated event {event} in calendar {calendar}" : "Vostede actualizou o evento {event} no calendario {calendar}",
    "Busy" : "Ocupado",
    "{actor} created todo {todo} in list {calendar}" : "{actor} creou os asuntos pendentes {todo} na lista {calendar}",
    "You created todo {todo} in list {calendar}" : "Vostede creou os asuntos pendentes {todo} na lista {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} eliminou os asuntos pendentes {todo} da lista {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Vostede eliminou os asuntos pendentes {todo} da lista {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} actualizou os asuntos pendentes {todo} na lista {calendar}",
    "You updated todo {todo} in list {calendar}" : "Vostede actualizou os asuntos pendentes {todo} na lista {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} resolveu os asuntos pendentes {todo} na lista {calendar}",
    "You solved todo {todo} in list {calendar}" : "Vostede resolveu os asuntos pendentes {todo} na lista {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} volveu abrir os asuntos pendentes {todo} na lista {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Vostede volveu abrir os asuntos pendentes {todo} na lista {calendar}",
    "Calendar and tasks" : "Calendario e tarefas",
    "A <strong>calendar</strong> was modified" : "Foi modificado un <strong>calendario</strong>",
    "A calendar <strong>event</strong> was modified" : "Foi modificado un <strong>evento</strong> do calendario",
    "A calendar <strong>todo</strong> was modified" : "Foi modificado un <strong>asunto pendente</strong> do calendario",
    "Death of %s" : "Falecemento de %s",
    "Contact birthdays" : "Aniversario do contacto",
    "Calendar:" : "Calendario:",
    "Date:" : "Data:",
    "Where:" : "Onde:",
    "Description:" : "Descrición:",
    "Untitled event" : "Evento sen título",
    "_%n year_::_%n years_" : ["%n ano","%n anos"],
    "_%n month_::_%n months_" : ["%n mes","%n meses"],
    "_%n day_::_%n days_" : ["%n día","%n días"],
    "_%n hour_::_%n hours_" : ["%n hora","%n horas"],
    "_%n minute_::_%n minutes_" : ["%n minuto","%n minutos"],
    "%s (in %s)" : "%s (n %s)",
    "%s (%s ago)" : "%s (hai %s)",
    "Calendar: %s" : "Calendario: %s",
    "Date: %s" : "Data: %s",
    "Description: %s" : "Descrición: %s",
    "Where: %s" : "Onde: %s",
    "%1$s via %2$s" : "%1$s mediante %2$s",
    "Invitation canceled" : "Convite cancelado",
    "Invitation updated" : "Convite actualizado",
    "Invitation" : "Convite",
    "Title:" : "Título:",
    "Time:" : "Hora:",
    "Location:" : "Lugar:",
    "Link:" : "Ligazón:",
    "Organizer:" : "Organizador:",
    "Attendees:" : "Asistentes:",
    "Accept" : "Aceptar",
    "Decline" : "Declinar",
    "More options …" : "Máis opcións…",
    "More options at %s" : "Máis opcións en %s",
    "Contacts" : "Contactos",
    "System in maintenance mode." : "Sistema en modo de mantemento",
    "Upgrade needed" : "É necesario anovar actualizar",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "É preciso configurar o seu %s para que empregue HTTPS para poder usar CalDAV e CardDAV con iOS / macOS.",
    "Configures a CalDAV account" : "Configurar unha conta de CalDAV",
    "Configures a CardDAV account" : "Configurar unha conta de CardDAV",
    "Events" : "Eventos",
    "Tasks" : "Tarefas",
    "Untitled task" : "Tarefa sen título",
    "Completed on %s" : "Rematado o %s",
    "Due on %s by %s" : "Caduca o %s por %s",
    "Due on %s" : "Caduca o %s",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "Terminación WebDAV",
    "There was an error updating your attendance status." : "Produciuse un erro ao actualizar o seu estado de asistencia.",
    "Please contact the organizer directly." : "Contacte directamente co organizador.",
    "Are you accepting the invitation?" : "Acepta vostede o convite?",
    "Tentative" : "Tentativa",
    "Save" : "Gardar",
    "Your attendance was updated successfully." : "A súa asistencia foi actualizada satisfactoriamente.",
    "Calendar server" : "Servidor do calendario",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Instale tamén a {calendarappstoreopen}aplicación do Calendario{linkclose} ou {calendardocopen}conecte os seus escritorio e móbil para sincronizalos ↗{linkclose}.",
    "Send invitations to attendees" : "Enviar convites aos asistentes",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Asegúrese de ter configurado correctamente {emailopen}o servidor de correo-e{linkclose}.",
    "Automatically generate a birthday calendar" : "Xerar automaticamente o calendario de aniversarios",
    "Birthday calendars will be generated by a background job." : "O calendario de aniversarios xerase cun traballo en segundo plano",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Por isto, non estarán dispoñíbeis inmediatamente tras activalos, senón que aparecerán após certo tempo",
    "Send notifications for events" : "Enviar notificacións para eventos",
    "Notifications are sent via background jobs, so these must occur often enough." : "As notificacións enviaranse mediante procesos en segundo plano, polo que estes teñen que suceder con frecuencia.",
    "Enable notifications for events via push" : "Activar o envío de notificacións do servidor para eventos",
    "Hello %s," : "Ola %s,",
    "The meeting »%1$s« with %2$s was canceled." : "A xuntanza «%1$s» con %2$s foi cancelada.",
    "The meeting »%1$s« with %2$s was updated." : "A xuntanza «%1$s» con %2$s foi actualizada.",
    "%1$s invited you to »%2$s«" : "%1$s convidouno a «%2$s»",
    "When:" : "Cando:"
},
"nplurals=2; plural=(n != 1);");
